cheesecake.model.Function

Package cheesecake :: Module model :: Class Function |
[hide private]
[frames] | no frames]

## Class Function
source code

      object --+
               |
    Documentable --+
                   |
                  Function

Instance Methods | [hide private]
Inherited from `Documentable`: `__getstate__`, `__init__`, `__repr__`, `dottedNameToFullName`, `fullName`, `name2fullname`, `resolveDottedName`, `setup`, `shortdocstring` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Variables | [hide private]
kind |
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

    ### kind Value:
        'Function'